@@ -70,6 +70,10 @@ namespace galera
 
             private:
 
+                // Non-copyable
+                Consumer(const Consumer&);
+                Consumer& operator=(const Consumer&);
+
                 gu::Cond   cond_;
                 TrxHandle* trx_;
             };
@@ -95,7 +99,7 @@ namespace galera
                    gcache::GCache& gcache,
                    const std::string& peer,
                    int version);
-            ~Sender();
+            virtual ~Sender();
 
             void send(wsrep_seqno_t first, wsrep_seqno_t last);
 
@@ -135,7 +139,6 @@ namespace galera
                 :
                 senders_(),
                 monitor_(),
-                gcs_(gcs),
                 gcache_(gcache) { }
             void run(const gu::Config& conf,
                      const std::string& peer,
@@ -149,7 +152,6 @@ namespace galera
             std::set<AsyncSender*> senders_;
             // use monitor instead of mutex, it provides cancellation point
             gu::Monitor            monitor_;
-            GCS_IMPL&              gcs_;
             gcache::GCache&        gcache_;
         };
 
