@@ -20,6 +20,8 @@
 #include "gcs_group.hpp"
 #include "gcs_gcache.hpp"
 
+#include "gu_debug_sync.hpp"
+
 #include <string.h> // for mempcpy
 #include <errno.h>
 
@@ -379,6 +381,7 @@ gcs_core_send (gcs_core_t*          const conn,
 #endif
         ret = core_msg_send_retry (conn, conn->send_buf, send_size,
                                    GCS_MSG_ACTION);
+        GU_DBUG_SYNC_WAIT("gcs_core_after_frag_send");
 #ifdef GCS_CORE_TESTING
 //        gu_lock_step_wait (&conn->ls); // pause after every fragment
 //        gu_info ("Sent %p of size %zu, ret: %zd. Total sent: %zu, left: %zu",
@@ -637,7 +640,6 @@ core_handle_act_msg (gcs_core_t*          core,
         else if (gu_unlikely(ret < 0)){
             gu_fatal ("Failed to handle action fragment: %zd (%s)",
                       ret, strerror(-ret));
-            assert (0);
             return -ENOTRECOVERABLE;
         }
     }
@@ -1082,7 +1084,6 @@ ssize_t gcs_core_recv (gcs_core_t*          conn,
         case GCS_MSG_ACTION:
             ret = core_handle_act_msg(conn, recv_msg, recv_act);
             assert (ret == recv_act->act.buf_len || ret <= 0);
-            assert (recv_act->sender_idx >= 0    || ret == 0);
             break;
         case GCS_MSG_LAST:
             ret = core_handle_last_msg(conn, recv_msg, &recv_act->act);
